<?

##
## implib.php3
##
## IMP v1.1
## Copywrite 1998 Charles J. Hagenbuch <chuck@osmos.ml.org>
##
## This code is under the GNU Public License
## See the file COPYING in this directory
##


##
## Defaults
##

$default_server  = "wso.williams.edu";  # default IMAP server to connect to
$default_folders = "mail/";             # default directory to look in for mail folders
$default_secure  = 1;                   # Use SSL for cookies if it is a secure connection

$path_to_sendmail = "/usr/sbin/sendmail";
$path_to_imap     = "/usr/local/apache/libexec/imap.so";

##
## Functions
##


// algorithm contributed by Richard Lynch: <lynch@lscorp.com>

function fill_paragraphs($text, $wrap=80, $break="\n") {
  // break the text into paragraphs by stripping off any newline characters
  $paragraphs = split("\n", "$text");
  
  // format one paragraph at a time
  for ($i = 0; $i < sizeof($paragraphs); $i++) {
    $paragraphs[$i] = textwrap($paragraphs[$i], $wrap, $break);
  }
  // concatenate the formatted paragraphs into a single string
  // with a newline character between each element
  return implode($break, $paragraphs);
}


// Contributed by Richard Lynch: <lynch@lscorp.com>

function textwrap($text, $wrap=80, $break="\n") {
  $len = strlen($text);
  if ($len > $wrap) {
    $result = '';         // massaged text
    $lastWhite = 0;  // position of last whitespace char
    $lastChar = 0;   // position of last char
    $lastBreak = 0;  // position of last break
    
    // while there is text to process
    while ($lastChar < $len) {
      $char = substr($text, $lastChar, 1);  // get the next character
      
      // if we are beyond the wrap boundary and there is a place to break
      if (($lastChar - $lastBreak > $wrap) && ($lastWhite > $lastBreak)) {
        $result .= substr($text, $lastBreak, ($lastWhite - $lastBreak)) . $break;
	$lastChar = $lastWhite + 1;
	$lastBreak = $lastChar;
      }
      
      // might include other characters as valid whitespace...
      if ($char == ' ' || $char == chr(13) || $char == chr(10)) {
        $lastWhite = $lastChar;            // note the position of the last white space
      }
      $lastChar = $lastChar + 1;           // advance the last character position by one
    }
    $result .= substr($text, $lastBreak);  // build line
  }
  else {
    $result = $text;  // if everything can fit on the line
  }
  return $result;
}


function gm_offset() {
  $offset = ((date("H") - gmdate("H")));
  if ($offset >= 0) { return sprintf("+%02d", $offset) . "00"; }
  else { return sprintf("-%02d", -$offset) . "00"; }
}


function validate_login($server, $mailbox, $user, $pass) {
  if (! ($mbox = imap_open("{$server}$mailbox", $user, $pass)) ) {
    echo "<script language=javascript>\n
          <!--\n
	  document.location=\"login.php3?reason=timeout\";\n
	  //-->\n
	  </script>\n
    ";
  }
  return $mbox;
}


function mailfrom($to, $from, $subject, $hdrs, $message) {
  global $path_to_sendmail;
  
  $mail = popen("$path_to_sendmail -t -f $to", "w");
  
  $result  = fputs($mail, "To: $to\n");
  $result += fputs($mail, "From: $from\n");
  $result += fputs($mail, $hdrs);
  $result += fputs($mail, "Subject: $subject\n\n");
  $result += fputs($mail, $message);
  
  pclose($mail);
  
  if ($result > 0) { return 1; }
  else { return 0; }
}


# cookie setting functions

# the strtr in the cookie setting functions is NOT encryption. SSL is
# relied on for the encryption - if you don't use SSL, NONE of this is
# secure. this is just in case cookie values get displayed on the screen,
# or something similar. If someone has a better way, please let me know.

function setuser($user) {
  global $SERVER_PORT;
  
  if ($SERVER_PORT == 443) { $secure = 1; }
  else { $secure = 0; }
  
  setcookie("chuckmIMPuser", strtr($user, " abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890~!@#$%^&*()_+=-", "1234567890-=ABCDEFGHIJKLMNOPQRSTUVWXYZ~!@#$%^&*()_+abcdefghijklm nopqrstuvwxyz"), "time()+900", "", "", $secure);
}

function setpass($pass) {
  global $SERVER_PORT;
  
  if ($SERVER_PORT == 443) { $secure = 1; }
  else { $secure = 0; }
  
  setcookie("chuckmIMPpass", strtr($pass, " abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890~!@#$%^&*()_+=-", "1234567890-=ABCDEFGHIJKLMNOPQRSTUVWXYZ~!@#$%^&*()_+abcdefghijklm nopqrstuvwxyz"), "time()+900", "", "", $secure);
}

function setsrvr($srvr) {
  global $default_server, $SERVER_PORT;
  
  if ($SERVER_PORT == 443) { $secure = 1; }
  else { $secure = 0; }
  
  if ($srvr != "") {
    setcookie("chuckmIMPsrvr", strtr($srvr, " abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890~!@#$%^&*()_+=-", "1234567890-=ABCDEFGHIJKLMNOPQRSTUVWXYZ~!@#$%^&*()_+abcdefghijklm nopqrstuvwxyz"), "time()+900", "", "", $secure);
    return $srvr;
  } else {
    setcookie("chuckmIMPsrvr", strtr($default_server, " abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890~!@#$%^&*()_+=-", "1234567890-=ABCDEFGHIJKLMNOPQRSTUVWXYZ~!@#$%^&*()_+abcdefghijklm nopqrstuvwxyz"), "time()+900", "", "", $secure);
    return $default_server;
  }
}

function setfldr($fldr) {
  global $default_folders, $SERVER_PORT;
  
  if ($SERVER_PORT == 443) { $secure = 1; }
  else { $secure = 0; }
  
  if ($fldr != "") {
    setcookie("chuckmIMPfldr", strtr($fldr, " abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890~!@#$%^&*()_+=-", "1234567890-=ABCDEFGHIJKLMNOPQRSTUVWXYZ~!@#$%^&*()_+abcdefghijklm nopqrstuvwxyz"), "time()+900", "", "", $secure);
    return $fldr;
  } else {
    setcookie("chuckmIMPfldr", strtr($default_folders, " abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890~!@#$%^&*()_+=-", "1234567890-=ABCDEFGHIJKLMNOPQRSTUVWXYZ~!@#$%^&*()_+abcdefghijklm nopqrstuvwxyz"), "time()+900", "", "", $secure);
    return $default_folders;
  }
}


# cookie retrieval functions

function getuser() {
  global $chuckmIMPuser;
  
  return strtr($chuckmIMPuser,"1234567890-=ABCDEFGHIJKLMNOPQRSTUVWXYZ~!@#$%^&*()_+abcdefghijklm nopqrstuvwxyz"," abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890~!@#$%^&*()_+=-");
}

function getpass() {
  global $chuckmIMPpass;
  
  return strtr($chuckmIMPpass,"1234567890-=ABCDEFGHIJKLMNOPQRSTUVWXYZ~!@#$%^&*()_+abcdefghijklm nopqrstuvwxyz"," abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890~!@#$%^&*()_+=-");
}

function getsrvr() {
  global $chuckmIMPsrvr, $default_server;
  
  if (isset($chuckmIMPsrvr)) {
    return strtr($chuckmIMPsrvr,"1234567890-=ABCDEFGHIJKLMNOPQRSTUVWXYZ~!@#$%^&*()_+abcdefghijklm nopqrstuvwxyz"," abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890~!@#$%^&*()_+=-");
  } else {
    return $default_server;
  }
}

function getfldr() {
  global $chuckmIMPfldr, $default_folders;
  
  if (isset($chuckmIMPfldr)) {
    return strtr($chuckmIMPfldr,"1234567890-=ABCDEFGHIJKLMNOPQRSTUVWXYZ~!@#$%^&*()_+abcdefghijklm nopqrstuvwxyz"," abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890~!@#$%^&*()_+=-");
  } else {
    return $default_folders;
  }
}


##
## End IMPlib
##

?>
